@@ -227,8 +227,16 @@ func TestToDefinition(t *testing.T) {
 					},
 				},
 			},
+			"machine_checks": []any{
+				map[string]any{
+					"command":      []any{"curl", "https://fly.io"},
+					"image":        "curlimages/curl",
+					"entrypoint":   []any{"/bin/sh"},
+					"kill_signal":  "SIGKILL",
+					"kill_timeout": "5s",
+				},
+			},
 		},
-
 		"experimental": map[string]any{
 			"cmd":           []any{"cmd"},
 			"entrypoint":    []any{"entrypoint"},
@@ -356,6 +364,15 @@ func TestToDefinition(t *testing.T) {
 						"path":     "/check2",
 					},
 				},
+				"machine_checks": []any{
+					map[string]any{
+						"command":      []any{"curl", "https://fly.io"},
+						"image":        "curlimages/curl",
+						"entrypoint":   []any{"/bin/sh"},
+						"kill_signal":  "SIGKILL",
+						"kill_timeout": "5s",
+					},
+				},
 			},
 		},
 	}, definition)
