@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
+	"maps"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -135,7 +136,7 @@ func (state *launchState) scannerRunCallback(ctx context.Context) error {
 			cfg, err := appconfig.LoadConfig(state.sourceInfo.MergeConfig.Name)
 			if err == nil {
 				// In theory, any part of the configuration could be merged here, but for now
-				// we will only copy over the processes, release command, volume, and statics
+				// we will only copy over the processes, release command, env, volume, and statics
 				if state.sourceInfo.Processes == nil {
 					state.sourceInfo.Processes = cfg.Processes
 				}
@@ -144,6 +145,16 @@ func (state *launchState) scannerRunCallback(ctx context.Context) error {
 					state.sourceInfo.ReleaseCmd = cfg.Deploy.ReleaseCommand
 				}
 
+				if len(cfg.Env) > 0 {
+					if len(state.sourceInfo.Env) == 0 {
+						state.sourceInfo.Env = cfg.Env
+					} else {
+						clone := maps.Clone(state.sourceInfo.Env)
+						maps.Copy(clone, cfg.Env)
+						state.sourceInfo.Env = clone
+					}
+				}
+
 				if len(state.sourceInfo.Volumes) == 0 && len(cfg.Mounts) > 0 {
 					state.sourceInfo.Volumes = []scanner.Volume{cfg.Mounts[0]}
 				}
